@@ -18,14 +18,14 @@ os.chdir(os.path.dirname(os.path.abspath(__file__)))
 device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')
 
 # hyperparameter
-dataset = 'Fashion_Mnist'
+# dataset = 'MNIST'
 num_nodes = 1
 global_rounds = 100
 local_epochs = 1
 local_steps = 1
 batch_size = 4
 
-def run_global():
+def run_global(dataset):
     # split data
     dt = data_process(dataset)
     trainset,testset = dt.train_dataset, dt.test_dataset
