@@ -43,25 +43,25 @@ class data_process:
 
 
         # show image
-        batch_size = 4
-        trainloader = DataLoader(self.train_dataset, batch_size=batch_size,
-                                          shuffle=True, num_workers=2)
-        classes = ('plane', 'car', 'bird', 'cat',
-           'deer', 'dog', 'frog', 'horse', 'ship', 'truck')
-        def imshow(img):
-            img = img / 2 + 0.5     # unnormalize
-            npimg = img.numpy()
-            plt.imshow(np.transpose(npimg, (1, 2, 0)))
-            plt.show()
+        # batch_size = 4
+        # trainloader = DataLoader(self.train_dataset, batch_size=batch_size,
+        #                                   shuffle=True, num_workers=2)
+        # classes = ('plane', 'car', 'bird', 'cat',
+        #    'deer', 'dog', 'frog', 'horse', 'ship', 'truck')
+        # def imshow(img):
+        #     img = img / 2 + 0.5     # unnormalize
+        #     npimg = img.numpy()
+        #     plt.imshow(np.transpose(npimg, (1, 2, 0)))
+        #     plt.show()
 
-        # get some random training images
-        dataiter = iter(trainloader)
-        images, labels = dataiter.next()
+        # # get some random training images
+        # dataiter = iter(trainloader)
+        # images, labels = dataiter.next()
 
-        # show images
-        imshow(torchvision.utils.make_grid(images))
-        # print labels
-        print(' '.join('%5s' % classes[labels[j]] for j in range(batch_size)))
+        # # show images
+        # imshow(torchvision.utils.make_grid(images))
+        # # print labels
+        # print(' '.join('%5s' % classes[labels[j]] for j in range(batch_size)))
         
 
     def split_dataset(self, num_nodes, alpha, method = 'dirichlet'):
